@@ -18,12 +18,12 @@ use crate::plugins::{Plugin, PluginType, VERSION_REGEX};
 use crate::registry::REGISTRY;
 use crate::runtime_symlinks::is_runtime_symlink;
 use crate::toolset::outdated_info::OutdatedInfo;
-use crate::toolset::{install_state, is_outdated_version, ToolRequest, ToolVersion, Toolset};
+use crate::toolset::{ToolRequest, ToolVersion, Toolset, install_state, is_outdated_version};
 use crate::ui::progress_report::SingleReport;
 use crate::{dirs, env, file, hash, lock_file, plugins, versions_host};
 use backend_type::BackendType;
 use console::style;
-use eyre::{bail, eyre, Result, WrapErr};
+use eyre::{Result, WrapErr, bail, eyre};
 use indexmap::IndexSet;
 use itertools::Itertools;
 use regex::Regex;
