@@ -2322,21 +2322,36 @@ const completionSpec: Fig.Spec = {
           description:
             "List available tasks to execute\nThese may be included from the config file or from the project's .mise/tasks directory\nmise will merge all tasks from all parent directories into this list.",
           options: [
-            {
-              name: "--no-header",
-              description: "Do not print table header",
-              isRepeatable: false,
-            },
             {
               name: ["-x", "--extended"],
               description: "Show all columns",
               isRepeatable: false,
             },
+            {
+              name: "--no-header",
+              description: "Do not print table header",
+              isRepeatable: false,
+            },
             {
               name: "--hidden",
               description: "Show hidden tasks",
               isRepeatable: false,
             },
+            {
+              name: ["-g", "--global"],
+              description: "Only show global tasks",
+              isRepeatable: false,
+            },
+            {
+              name: ["-J", "--json"],
+              description: "Output in JSON format",
+              isRepeatable: false,
+            },
+            {
+              name: ["-l", "--local"],
+              description: "Only show non-global tasks",
+              isRepeatable: false,
+            },
             {
               name: "--sort",
               description: "Sort by column. Default is name.",
@@ -2355,11 +2370,6 @@ const completionSpec: Fig.Spec = {
                 suggestions: ["asc", "desc"],
               },
             },
-            {
-              name: ["-J", "--json"],
-              description: "Output in JSON format",
-              isRepeatable: false,
-            },
           ],
         },
         {
@@ -2477,21 +2487,36 @@ const completionSpec: Fig.Spec = {
         },
       ],
       options: [
-        {
-          name: "--no-header",
-          description: "Do not print table header",
-          isRepeatable: false,
-        },
         {
           name: ["-x", "--extended"],
           description: "Show all columns",
           isRepeatable: false,
         },
+        {
+          name: "--no-header",
+          description: "Do not print table header",
+          isRepeatable: false,
+        },
         {
           name: "--hidden",
           description: "Show hidden tasks",
           isRepeatable: false,
         },
+        {
+          name: ["-g", "--global"],
+          description: "Only show global tasks",
+          isRepeatable: false,
+        },
+        {
+          name: ["-J", "--json"],
+          description: "Output in JSON format",
+          isRepeatable: false,
+        },
+        {
+          name: ["-l", "--local"],
+          description: "Only show non-global tasks",
+          isRepeatable: false,
+        },
         {
           name: "--sort",
           description: "Sort by column. Default is name.",
@@ -2510,11 +2535,6 @@ const completionSpec: Fig.Spec = {
             suggestions: ["asc", "desc"],
           },
         },
-        {
-          name: ["-J", "--json"],
-          description: "Output in JSON format",
-          isRepeatable: false,
-        },
       ],
       args: {
         name: "task",
